
uniform float edgeScale;
const float edgeInOrthogonal = 0.005;
const float edgeInPerspective = 0.0025;
const float edgeOffset = 0.005;

layout (triangles) in;
layout (triangle_strip, max_vertices=6) out;

in vData {
	vec2 vTexCoord;
	vec3 normal;
} vertex[];

out fData {
	vec2 vTexCoord;
	vec3 normal;
	float edge;
} frag;

void main() {
	for(int i=0; i<3; i++)
	{
		frag.normal = vertex[i].normal;
		frag.vTexCoord = vertex[i].vTexCoord;
		frag.edge = 0.0;
		gl_Position = gl_ProjectionMatrix * gl_in[i].gl_Position;
		EmitVertex();
	}
	EndPrimitive();

	vec4 distance;
	float dis2 = 1.0;

	float scale;
	if(gl_ProjectionMatrix[3].w == 0)
	{
		scale = edgeInPerspective * edgeScale;
		distance = vec4(gl_ProjectionMatrix[0].w, gl_ProjectionMatrix[1].w, gl_ProjectionMatrix[2].w, 0.0) - gl_in[0].gl_Position;
		dis2 = distance.x * distance.x + 
					distance.y * distance.y +
					distance.z * distance.z;
		dis2 = max(1.0 ,dis2);
		dis2 = min(4.0,dis2);
	}
	else
	{
		scale = edgeInOrthogonal * edgeScale;
	}

	for(int i=0; i<3; i++)
	{
		frag.normal = vertex[i].normal;
		frag.vTexCoord = vertex[i].vTexCoord;
		frag.edge = 1.0;
		
		gl_Position = gl_ProjectionMatrix * gl_in[i].gl_Position;
		gl_Position = gl_Position + normalize(gl_ProjectionMatrix * vec4(frag.normal , 0.0)) * scale * dis2;
		gl_Position.z = gl_Position.z + edgeOffset;
		EmitVertex();
	}
	EndPrimitive();
}